=====
pySRA
=====

.. image:: https://img.shields.io/pypi/v/pysra.svg
    :target: https://pypi.python.org/pypi/pysra
    :alt: PyPi Cheese Shop

.. image:: https://img.shields.io/travis/arkottke/pysra.svg
    :target: https://travis-ci.org/arkottke/pysra
    :alt: Build Status

.. image:: https://readthedocs.org/projects/pysra/badge/?version=latest&style=flat
    :target: https://pysra.readthedocs.org
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/arkottke/pysra/badge.svg?branch=master
    :target: https://coveralls.io/github/arkottke/pysra?branch=master
    :alt: Test Coverage

.. image:: https://landscape.io/github/arkottke/pysra/master/landscape.svg?style=flat
    :target: https://landscape.io/github/arkottke/pysra/master
    :alt: Code Health

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://github.com/arkottke/pysra/blob/master/LICENSE
    :alt: License

.. image:: https://zenodo.org/badge/8959678.svg
   :target: https://zenodo.org/badge/latestdoi/8959678

Site response analyses implemented in Python.

* Free software: MIT license
* Documentation: https://pysra.readthedocs.org.


